/****************************************************************************
* File Name    : rl_sensor.c
* Version      : 
* Device(s)    : R5F1057A
* Tool-Chain   : CCRL
* Description  : 
* Creation Date: 2018/08/08
****************************************************************************/

/****************************************************************************
Includes
****************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_userdefine.h"
#include "r_cg_adc.h"
#include "r_cg_dtc.h"
#include "r_cg_port.h"

#include "rl_sensor.h"

/****************************************************************************
Pragma directive
****************************************************************************/

/****************************************************************************
Macro definitions
****************************************************************************/
#define	BATTERY_THRESHOLD	(205U)
#define	STS_AD_CONVERT		(1U)
#define	STS_AD_END			(0U)

#ifdef	CYCLE_30MINUTE
#define	CYCLE_CNT_MAX		(6U)
#endif


/****************************************************************************
Typedef definitions
****************************************************************************/

/****************************************************************************
Global variables and functions
****************************************************************************/
#pragma address g_adc_sensor = 0xFFE00U
uint8_t 	g_adc_sensor[4];    /* A/D converted data buffer    */

static uint8_t const g_sensor_port[4] = 
{ /* sensor enable port data      */
    0b11110011,                         /* for illuminance sensor       */
    0b11110111,                         /* for humidity sensor          */
    0b11111111,
    0b11111111
};

volatile	uint8_t	g_sensor_pt;
uint8_t		g_sensor_dt[100U][4U];

#ifdef	CYCLE_30MINUTE
#define	CYCLE_CNT_MAX		(6U)
uint8_t		g_adc_cycle_cnt;
#endif

void R_ADC_for_sensor(void);
/****************************************************************************
* Function Name: rl_SENSOR_measurement
* Description  : This feature, do the sensor measurement.
* Arguments    : None
* Return Value : None
****************************************************************************/
void	rl_SENSOR_measurement(void)
{
    uint8_t adinput;
    
#ifdef		CYCLE_30MINUTE
	g_adc_cycle_cnt++;                  /* 30minutes operation mode     */
	if( CYCLE_CNT_MAX > g_adc_cycle_cnt )
	{
		return;
	}
	g_adc_cycle_cnt = 0U;
#endif

/* start A/D converter to measure Vdd    */

    DI();                               /* disable vector interrupt     */
    R_ADC_Create();                     /* set A/D operation mode       */

/* start A/Dconversion internal reference voltage   */

	R_ADC_Start();                      /* start A/D conversion         */

    P5 = 0b11111101;                    /* Temperature_Circuit_Set      */
    HALT();                             /* wait for conversion end      */
    NOP();

    ADIF = 0U;                          /* clear A/D interrupt flag     */

    P5 = 0b11111001;                    /* Illuminance_Circuit_Set      */
    HALT();                             /* wait for next conversion end */
    NOP();

    adinput = ADCRH;                    /* get A/D conversion result    */

    ADM0 = 0x00;                        /* stop A/D converter           */

    ADIF = 0U;                          /* clear A/D interrupt flag     */
    EI();                               /* enable vector intrrupt       */

	if( BATTERY_THRESHOLD >= adinput )  /* check battery voltage   */
	{

/* change A/D mode to scan mode     */
		R_ADC_for_sensor();             /* change A/D to sensor         */
		R_DTC_Create();                 /* set DTC operation mode       */
		R_DTCD0_Start();                /* start DTC                    */
		R_ADC_Start();                  /* start A/D conversion         */

		HALT();                         /* wait for A/Dconversion end   */
		NOP();

		R_ADC_Stop();                   /* stop A/D converter           */
        ADM0 = 0x00;

/* store result to buffer   */
        g_sensor_dt[g_sensor_pt][0] = adinput;
        g_sensor_dt[g_sensor_pt][1] = g_adc_sensor[0];
        g_sensor_dt[g_sensor_pt][2] = g_adc_sensor[1];
        g_sensor_dt[g_sensor_pt][3] = g_adc_sensor[2];
        g_sensor_pt++;

	}

}

/***********************************************************************************************************************
* Function Name: R_ADC_for_sensor
* Description  : This function change AD to sensor.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_ADC_for_sensor(void)
{
    ADM0 = 0x00;                        /* clear A/D converter mode             */
    ADIF = 0;
    ADM0 = 0b01011100;                  /* change to scan mode                  */
    ADS  = 0x00;                        /* when scan mode,ADS must be 0x00      */
    ADCE = 1U;                          /* A/D voltage comparator operation start*/

}

